<?xml version="1.0" encoding="windows-1251"?>
<!DOCTYPE xsl:stylesheet>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output xmlns="http://www.w3.org/TR/xhtml1/strict" doctype-public="-//W3C//DTD XHTML 1.0 Strict//EN" encoding="Windows-1251" indent="yes" method="html" omit-xml-declaration="no" version="1.0" media-type="text/xml"/>
	
	<xsl:template match="/">
		<xsl:apply-templates select="/document"/>
	</xsl:template>
	
	<xsl:decimal-format decimal-separator = "." grouping-separator = "." />
	
	<xsl:template match="/document">
		<!--  ID       $parent_group_id -->
		<xsl:variable name="parent_group_id" select="blocks/parent_group_id"/>

		<!--     -     -->
		<xsl:if test="blocks/parent_group_id=0">
			<h1>
				<xsl:value-of disable-output-escaping="yes" select="blocks/name"/>
			</h1>
			<xsl:value-of disable-output-escaping="yes" select="blocks/description"/>
		</xsl:if>

		<!--      -    -->
		<xsl:if test="blocks/parent_group_id!=0">
			<h1>
				<xsl:value-of disable-output-escaping="yes" select=".//group[@id=$parent_group_id]/name"/>
			</h1>

			<!--    -->
			<p>
				<xsl:apply-templates select=".//group[@id=$parent_group_id]" mode="goup_path"/>
			</p>
		</xsl:if>

		<!--     -->
		<xsl:if test="count(.//group[@parent_id=$parent_group_id])">
			<dl class="file_archive">
				<xsl:apply-templates select=".//group[@parent_id=$parent_group_id]" mode="goups"/>
			</dl>
		</xsl:if>

		<!--     -->
		<xsl:if test="count(blocks/items/item[item_status=1])">
			<dl class="file_archive">
				<!--     -->
				<xsl:apply-templates select="blocks/items/item[item_status=1]"/>
			</dl>
		</xsl:if>

		<p>
			<!--        -->
			<xsl:if test="=1">
				<xsl:if test="blocks/items/count_items &gt; blocks/items/items_on_page">
					<strong>
						<xsl:call-template name="for">
							<xsl:with-param name="n" select="blocks/items/count_items div blocks/items/items_on_page"/>
							<xsl:with-param name="current_page" select="blocks/items/current_page"/>
						</xsl:call-template>
					</strong>
				</xsl:if>
			</xsl:if>
		</p>

		<!--    -->
		<xsl:if test="=1">
			<p>
				<a href="{blocks/url}"> "<xsl:value-of disable-output-escaping="yes" select="blocks/name"/>"</a>
			</p>
		</xsl:if>
	</xsl:template>

	<!--     -->
	<xsl:template match="blocks/items/item">
		<!--    -->
		<xsl:variable name="file_type">
			<xsl:call-template name="file_type">
				<xsl:with-param name="str" select="item_propertys/item_property[@xml_name = 'file']/property_file_path" />
			</xsl:call-template>
		</xsl:variable>

		<dt>
			<a href="{item_path}" >
				<xsl:value-of select="item_name"/>
			</a>
		</dt>
		<dd>
			<xsl:if test="$file_type = 'bmp.gif' or $file_type = 'png.gif'	or $file_type = 'jpg.gif' or $file_type = 'gif.gif'">	
				<!--     ( ) -->
				<xsl:if test="item_small_image != ''">
					<div class="left">
						<img src="{item_small_image}" class="news_img" alt="" style="padding: 2px; border: 1px solid #C6BEA7;"/>
					</div>
				</xsl:if>
			</xsl:if>

			<!--   -->
			<xsl:variable name="width_img">
				<xsl:choose>
					<xsl:when test="item_small_image != ''">
						<xsl:value-of select="item_small_image/@width + 20" />
					</xsl:when>
					<xsl:otherwise>0</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>

			<div style="padding-left: {$width_img}px;">
				<xsl:if test="item_description != ''">
					<div>
						<xsl:value-of disable-output-escaping="yes" select="item_description"/>
					</div>
				</xsl:if>
				<xsl:if test="item_propertys/item_property[@xml_name='file']/property_file_path != ''">
					<!--   -  -->
					<xsl:if test="$file_type = 'bmp.gif' or $file_type = 'png.gif'	or $file_type = 'jpg.gif' or $file_type = 'gif.gif'">	
						<b>:</b>&#xA0;<xsl:value-of select="item_propertys/item_property[@xml_name = 'file']/property_file_path/@width" />&#215;<xsl:value-of select="item_propertys/item_property[@xml_name = 'file']/property_file_path/@height" />
						<br/>
					</xsl:if>

					<b>:</b>&#xA0;<xsl:value-of select="format-number(item_propertys/item_property[@xml_name = 'file']/property_file_path/@size div 1024, '0.##')" /> <br/>
					<img src="/hostcmsfiles/images/icons/{$file_type}" style="margin: 0 5px -3px 0;"/>
					<a href="{item_propertys/item_property[@xml_name='file']/property_file_path}" target="_blank"></a>
				</xsl:if>
			</div>

			<div class="clearing"></div>
		</dd>
	</xsl:template>

	<!--     .  -->
	<xsl:template match="group" mode="goups">
		<dt>
			<xsl:if test="small_image!=''">
				<a href="{/document/blocks/url}{fullpath}" target="_blank">
					<img src="{small_image}"/>
			</a>&#xA0;</xsl:if>
			<a href="{/document/blocks/url}{fullpath}">
				<xsl:value-of select="name"/>
			</a>
				&#xA0;<span class="gray"><b><xsl:value-of disable-output-escaping="yes" select="count_all_items"/></b>&#xA0;<xsl:call-template name="declension">
				<xsl:with-param name="number" select="count_all_items" />
				</xsl:call-template></span>
		</dt>

		<xsl:if test="description != ''">
			<dd>
				<xsl:value-of disable-output-escaping="yes" select="description"/>
			</dd>
		</xsl:if>
	</xsl:template>

	<!--       .  -->
	<xsl:template match="group" mode="goup_path">
		<xsl:param name="parent_id" select="@parent_id"/>

		<xsl:apply-templates select="//group[@id=$parent_id]" mode="goup_path"/>

		<xsl:if test="@parent_id=0">
			<a href="{/document/blocks/url}">
				<xsl:value-of select="/document/blocks/name"/>
			</a>
		</xsl:if>

		<span class="path_arrow">&#x2192;</span>

		<a href="{/document/blocks/url}{fullpath}">
			<xsl:value-of select="name"/>
		</a>
	</xsl:template>

	<!--      -->
	<xsl:template name="file_type">
		<xsl:param name="str"/>

		<xsl:variable name="sub_str">
			<xsl:value-of select="substring-after($str, '.')" />
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="$sub_str = ''">file.gif</xsl:when>
			<xsl:when test="$sub_str = 'sql'">sql.gif</xsl:when>
			<xsl:when test="$sub_str = 'css'">css.gif</xsl:when>
			<xsl:when test="$sub_str = 'gif'">gif.gif</xsl:when>
			<xsl:when test="$sub_str = 'bmp'">bmp.gif</xsl:when>
			<xsl:when test="$sub_str = 'png'">png.gif</xsl:when>
			<xsl:when test="$sub_str = 'ico'">image.gif</xsl:when>
			<xsl:when test="$sub_str = 'xml'">xml.gif</xsl:when>
			<xsl:when test="$sub_str = 'xsl'">xsl.gif</xsl:when>
			<xsl:when test="$sub_str = 'rar'">rar.gif</xsl:when>
			<xsl:when test="$sub_str = 'pdf'">pdf.gif</xsl:when>
			<xsl:when test="$sub_str = 'rb'">rb.gif</xsl:when>
			<xsl:when test="$sub_str = 'mdb'">mdb.gif</xsl:when>
			<xsl:when test="$sub_str = 'h'">h.gif</xsl:when>
			<xsl:when test="$sub_str = 'xls'">xls.gif</xsl:when>
			<xsl:when test="$sub_str = 'cpp'">cpp.gif</xsl:when>
			<xsl:when test="$sub_str = 'chm'">chm.gif</xsl:when>
			<xsl:when test="$sub_str = 'doc' or $sub_str = 'docx'">doc.gif</xsl:when>
			<xsl:when test="$sub_str = 'htm' or $sub_str = 'html'">html.gif</xsl:when>
			<xsl:when test="$sub_str = 'php' or $sub_str = 'php3'">php.gif</xsl:when>
			<xsl:when test="$sub_str = 'jpg' or $sub_str = 'jpeg'">jpg.gif</xsl:when>
			<xsl:when test="$sub_str = 'fla' or $sub_str = 'fla'">flash.gif</xsl:when>
			<xsl:when test="$sub_str = 'zip' or $sub_str = 'gz' or $sub_str = '7z'">zip.gif</xsl:when>
			<xsl:when test="$sub_str = 'cdr' or $sub_str = 'ai' or $sub_str = 'eps'">vector.gif</xsl:when>
			<xsl:when test="$sub_str = 'ppt' or $sub_str = 'pptx' or $sub_str = 'pptm'">ppt.gif</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="file_type">
					<xsl:with-param name="str" select="$sub_str"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!--      -->
	<xsl:template name="for">
		<xsl:param name="i" select="0"/>
		<xsl:param name="n"/>
		<xsl:param name="current_page"/>
		
		<xsl:if test="$n &gt; $i">
			
			<!--   -->
			<xsl:if test="$i != 0 and $n &gt; $current_page">-</xsl:if>
			
			<!--    -->
			<xsl:if test="$i != $current_page">
				
				<!--    $parent_group_id    -->
				<xsl:variable name="parent_group_id" select="/document/blocks/parent_group_id"/>
				
				<!--       -->
				<xsl:variable name="group_link">
					<xsl:choose>
						<!--     (!=0) -->
						<xsl:when test="$parent_group_id != 0">
							<xsl:value-of select="/document/blocks//group[@id=$parent_group_id]/fullpath"/>
						</xsl:when>
						<!--     -        -->
						<xsl:otherwise></xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				
				<!--    -->
				<xsl:variable name="number_link">
					<xsl:choose>
						<!--     -->
						<xsl:when test="$i != 0">page-<xsl:value-of select="$i+1"/>/</xsl:when>
						<!--     -        -->
						<xsl:otherwise></xsl:otherwise>
					</xsl:choose>
				</xsl:variable>
				
				<a href="{/document/blocks/url}{$group_link}{$number_link}">
					<xsl:value-of select="$i+1"/>
				</a>
			</xsl:if>
			
			<!--     -->
			<xsl:if test="$i = $current_page">
				<span class="current">
					<xsl:value-of select="$i+1"/>
				</span>
			</xsl:if>
			
			<!--   .     ! -->
			<xsl:call-template name="for">
				<xsl:with-param name="i" select="$i + 1"/>
				<xsl:with-param name="n" select="$n"/>
				<xsl:with-param name="current_page" select="$current_page"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<!--    -->
	<xsl:template name="declension">
		<xsl:param name="number" select="number"/>

		<!--   -->
		<xsl:variable name="nominative">
			<xsl:text></xsl:text>
		</xsl:variable>

		<!--  ,   -->
		<xsl:variable name="genitive_singular">
			<xsl:text></xsl:text>
		</xsl:variable>

		<xsl:variable name="genitive_plural">
			<xsl:text></xsl:text>
		</xsl:variable>

		<xsl:variable name="last_digit">
			<xsl:value-of select="$number mod 10"/>
		</xsl:variable>

		<xsl:variable name="last_two_digits">
			<xsl:value-of select="$number mod 100"/>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="$last_digit = 1 and $last_two_digits != 11">
				<xsl:value-of select="$nominative"/>
			</xsl:when>
			<xsl:when test="$last_digit = 2 and $last_two_digits != 12
				or $last_digit = 3 and $last_two_digits != 13
				or $last_digit = 4 and $last_two_digits != 14">
				<xsl:value-of select="$genitive_singular"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$genitive_plural"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>